#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-scaling-image
version:              0.1.0.1
visibility:           public
id:                   gtk-scaling-image-0.1.0.1-2DbULfgEkliCFoEys0gOFu
key:                  gtk-scaling-image-0.1.0.1-2DbULfgEkliCFoEys0gOFu
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/gtk-scaling-image#readme
synopsis:             Generic GTK image scaling helpers for haskell-gi
description:
    Please see the README on Github at <https://github.com/taffybar/gtk-scaling-image#readme>

category:             Graphics
abi:                  b5b19866155fdcad5c15a7adece15250
exposed:              True
exposed-modules:      Graphics.UI.GIGtkScalingImage
hidden-modules:       Paths_gtk_scaling_image
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gtk-scaling-image-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gtk-scaling-image-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gtk-scaling-image-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-scaling-image
hs-libraries:         HSgtk-scaling-image-0.1.0.1-2DbULfgEkliCFoEys0gOFu
depends:
    base-4.18.2.1 gi-cairo-connector-0.1.1-7uynRCW1y2u1dK0uiof2Id
    gi-cairo-render-0.1.2-Kj3foQkl9TH1rrXqbiLLy2
    gi-gdk3-3.0.30-FYr0miE6cDgBeWfFoLEvjy
    gi-gdkpixbuf-2.0.32-HF29aMfV073CJREslGoIfr
    gi-gtk3-3.0.44-309fzdC4rCB3CsRHzS3G5F
    hslogger-1.3.2.0-D93Y2qjH7EfINBYoIXbCKD

haddock-interfaces:
    /usr/share/doc/haskell-gtk-scaling-image/html/gtk-scaling-image.haddock

haddock-html:         /usr/share/doc/haskell-gtk-scaling-image/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

